@@ -11,7 +11,7 @@ use Term::ANSIColor ();
 use Sys::Hostname qw( hostname );
 
 # ABSTRACT: Parallel SSH client
-our $VERSION = '0.99_02'; # TRIAL VERSION
+our $VERSION = '0.99_03'; # TRIAL VERSION
 
 
 sub main
@@ -80,10 +80,10 @@ sub new
   
   my $ok = 1;
   
-  foreach my $cluster (map { "$_" } @{ $self->{clusters} })
+  foreach my $cluster (map { "$_" } $self->clusters)
   {
     $cluster =~ s/^.*@//;
-    unless($self->config->clusters->{$cluster})
+    unless($self->cluster_list->{$cluster})
     {
       say STDERR "unknown cluster: $cluster";
       $ok = 0;
@@ -95,15 +95,15 @@ sub new
   $self;
 }
 
-sub config         { shift->{config}      }
-sub dry_run        { shift->{dry_run}     }
-sub color          { shift->{color}       }
-sub clusters       { shift->{clusters}    }
-sub command        { shift->{command}     }
-sub user           { shift->{user}        }
-sub server         { shift->{server}      }
-sub verbose        { shift->{verbose}     }
-sub serial         { shift->{serial}      }
+sub config         { shift->{config}        }
+sub dry_run        { shift->{dry_run}       }
+sub color          { shift->{color}         }
+sub clusters       { @{ shift->{clusters} } }
+sub command        { shift->{command}       }
+sub user           { shift->{user}          }
+sub server         { shift->{server}        }
+sub verbose        { shift->{verbose}       }
+sub serial         { shift->{serial}        }
 sub server_command { shift->config->server_command( default => 'clad --server' ) }
 sub ssh_command    { shift->config->ssh_command(    default => 'ssh' ) }
 sub ssh_options    { shift->config->ssh_options(    default => [ -o => 'StrictHostKeyChecking=no', 
@@ -123,6 +123,17 @@ sub alias
   });
 }
 
+sub cluster_list
+{
+  my($self) = @_;
+  $self->config->cluster( default => sub {
+    my %deprecated = $self->config->clusters( default => {} );
+    say STDERR "use of clusters key in configuration is deprecated, use cluster instead"
+        if %deprecated;
+    \%deprecated;
+  });
+}
+
 sub ret
 {
   my($self, $new) = @_;
@@ -138,10 +149,10 @@ sub host_length
   {
     my $length = 0;
   
-    foreach my $cluster (map { "$_" } @{ $self->{clusters} })
+    foreach my $cluster (map { "$_" } $self->clusters)
     {
       my $user = $cluster =~ s/^(.*)@// ? $1 : $self->user;
-      foreach my $host (@{ $self->config->clusters->{$cluster} })
+      foreach my $host (@{ $self->cluster_list->{$cluster} })
       {
         my $prefix = ($user ? "$user\@" : '') . $host;
         $length = length $prefix if length $prefix > $length;
@@ -170,7 +181,7 @@ sub run
   my $ret = 0;
   my @done;
   
-  foreach my $cluster (map { "$_" } @{ $self->{clusters} })
+  foreach my $cluster (map { "$_" } $self->clusters)
   {
     my $user = $cluster =~ s/^(.*)@// ? $1 : $self->user;
 
@@ -178,7 +189,7 @@ sub run
     $env{CLUSTER}      //= $cluster; # deprecate
     $env{CLAD_CLUSTER} //= $cluster;
 
-    foreach my $host (@{ $self->config->clusters->{$cluster} })
+    foreach my $host (@{ $self->cluster_list->{$cluster} })
     {
       my $prefix = ($user ? "$user\@" : '') . $host;
       if($self->dry_run)
@@ -298,7 +309,7 @@ use AE;
 use AnyEvent::Open3::Simple 0.76;
 use YAML::XS qw( Dump );
 
-our $VERSION = '0.99_02'; # TRIAL VERSION
+our $VERSION = '0.99_03'; # TRIAL VERSION
 
 sub new
 {
@@ -384,7 +395,6 @@ sub print_line
   my($self, $code, $line) = @_;
   
   print Term::ANSIColor::color($self->color) if $self->is_color;
-  $DB::single = 1;
   printf "[%@{[ $self->clad->host_length ]}s %-4s] ", $self->prefix, $code;
   print Term::ANSIColor::color('reset') if $self->is_color;
   print $line, "\n";
@@ -406,7 +416,7 @@ App::clad - Parallel SSH client
 
 =head1 VERSION
 
-version 0.99_02
+version 0.99_03
 
 =head1 SYNOPSIS
 
